For each ticker in the data frame of companies, get_info grabs
financial data using the quantmod package and generates a list with
three sub-lists. Also writes .RData files to the user's temporary directory.
If cancelled partway through, get_info is able to find and re-read this
data, quickly resuming its progress. Once complete, get_info deletes
all used temporary data.
Parameter data frame defaults to provided companies_r3k16 data set if not specified.