`install_yfinance()` installs just the yfinance python package and it's direct dependencies. Users may be asked to install miniconda for the python installations. Even if you first decline it, you can later install miniconda by running [`reticulate::install_miniconda()`]
install_yfinance(..., envname = "r-qmj", new_env = identical(envname, "r-qmj"))No return value, called for installing Python yfinance module
other arguments passed to [`reticulate::py_install()`]
The name, or full path, of the environment in which Python
packages are to be installed. When NULL (the default), the active
environment as set by the RETICULATE_PYTHON_ENV variable will be used;
if that is unset, then the r-reticulate environment will be used.
Delete `envname` if it already exists