Processes raw balance sheet data produced from quantmod into a tidy data frame. Raw balance sheet data must be formatted in a list such that every element is a data frame or matrix containing quantmod data.
tidy_balancesheets(x)Returns a data set that's been 'tidied' up for use by other functions in this package.
A list of raw cash flow data produced from quantmod
tidy_balancesheets produces a data frame that is
'tidy' or more readily readable by a user and usable by
other functions within this package.
get_info
tidyinfo
tidy_cashflows
tidy_incomestatements