Learn R Programming

qmj (version 0.2.1)

tidy_incomestatements: Makes raw incomestatement data usable and readable.

Description

Tidies raw income statement data produced from quantmod and returns the tidied data frame. Raw income statement data must be formatted in a list such that every element is a data frame or matrix containing quantmod data.

Usage

tidy_incomestatements(x)

Value

Returns a data set that's been 'tidied' up for use by other functions in this package.

Arguments

x

A list of raw incomestatement file data produced from quantmod

Details

tidy_incomestatements produces a data frame that is 'tidy' or more readily readable by a user and usable by other functions within this package.

See Also

get_info

tidyinfo

tidy_cashflows

tidy_balancesheets