Tidies raw prices and returns a tidied, usable data frame.
Raw data should be structured identically to that produced
by get_prices(), as this function depends on that structure.
Usage
tidy_prices(x)
Value
Returns a data set that's been 'tidied' up for use
by other functions in this package.
data.frame of cleaned prices
Arguments
x
Raw daily data, as produced by get_prices()
Functions
tidy_prices(): combines relevant columns from the original price
data set.
Convert certain columns into character in order to
bypass the warning generated by dplyr::bind_rows()
Details
tidy_prices produces a data frame that is 'tidy' or
more readily readable by a user and usable by other functions
within this package.