Learn R Programming

qmj (version 0.2.1)

tidyinfo: Formats raw financial data.

Description

tidyinfo works by formatting and curtailing the raw data generated by quantmod (and, by extension, the get_info function of this package)

Usage

tidyinfo(x)

Value

Returns a data set that is usable by the other functions of this package, as well as being generally more readable.

data.frame of cleaned info (cash flows, income statements, balance sheets)

Arguments

x

A list of lists of financial statements. Generated from get_info(companies).

See Also

get_info

tidy_cashflows

tidy_balancesheets

tidy_incomestatements

Examples

Run this code
# \donttest{
if (reticulate::py_module_available("yfinance")) {
  my_companies <- data.frame(ticker = c('GOOG', 'IBM'))
  raw_data <- get_info(my_companies)
  financials <- tidyinfo(raw_data)
}
# }

Run the code above in your browser using DataLab