Tidies raw income statement data produced from quantmod and returns the tidied data frame. Raw income statement data must be formatted in a list such that every element is a data frame or matrix containing quantmod data.
tidy_incomestatements(x)Returns a data set that's been 'tidied' up for use by other functions in this package.
A list of raw incomestatement file data produced from quantmod
tidy_incomestatements produces a data frame that is 'tidy'
or more readily readable by a user and usable by other functions within
this package.
get_info
tidyinfo
tidy_cashflows
tidy_balancesheets