powered by
tidyinfo works by formatting and curtailing the raw data generated by quantmod (and, by extension, the get_info function of this package)
tidyinfo
get_info
tidyinfo(x)
Returns a data set that is usable by the other functions of this package, as well as being generally more readable.
data.frame of cleaned info (cash flows, income statements, balance sheets)
A list of lists of financial statements. Generated from get_info(companies).
tidy_cashflows
tidy_balancesheets
tidy_incomestatements
# \donttest{ if (reticulate::py_module_available("yfinance")) { my_companies <- data.frame(ticker = c('GOOG', 'IBM')) raw_data <- get_info(my_companies) financials <- tidyinfo(raw_data) } # }
Run the code above in your browser using DataLab